@@ -1,5 +1,5 @@
 package Business::PayPal::API::AuthorizationRequest;
-$Business::PayPal::API::AuthorizationRequest::VERSION = '0.72';
+$Business::PayPal::API::AuthorizationRequest::VERSION = '0.73';
 use 5.008001;
 use strict;
 use warnings;
@@ -35,8 +35,8 @@ sub DoAuthorizationRequest {
 
     my $request
         = SOAP::Data->name(
-        DoAuthorizationRequest => \SOAP::Data->value( @ref_trans ) )
-        ->type( "ns:AuthorizationRequestType" );
+        DoAuthorizationRequest => \SOAP::Data->value(@ref_trans) )
+        ->type("ns:AuthorizationRequestType");
 
     my $som = $self->doCall( DoAuthorizationReq => $request )
         or return;
@@ -52,7 +52,8 @@ sub DoAuthorizationRequest {
     $self->getFields(
         $som, $path,
         \%response,
-        {   TransactionID => 'TransactionID',
+        {
+            TransactionID => 'TransactionID',
             Amount        => 'Amount',
         }
     );
@@ -72,7 +73,7 @@ Business::PayPal::API::AuthorizationRequest - PayPal AuthorizationRequest API
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =head1 SYNOPSIS
 
