@@ -1,5 +1,5 @@
 package Business::PayPal::API::GetBalance;
-$Business::PayPal::API::GetBalance::VERSION = '0.72';
+$Business::PayPal::API::GetBalance::VERSION = '0.73';
 use 5.008001;
 use strict;
 use warnings;
@@ -17,9 +17,8 @@ sub GetBalance {
     my @trans = ( $self->version_req, );
 
     my $request
-        = SOAP::Data->name(
-        GetBalanceRequest => \SOAP::Data->value( @trans ) )
-        ->type( "ns:GetBalanceRequestType" );
+        = SOAP::Data->name( GetBalanceRequest => \SOAP::Data->value(@trans) )
+        ->type("ns:GetBalanceRequestType");
 
     my $som = $self->doCall( GetBalanceReq => $request )
         or return;
@@ -35,7 +34,8 @@ sub GetBalance {
     $self->getFields(
         $som, $path,
         \%response,
-        {   Balance          => 'Balance',
+        {
+            Balance          => 'Balance',
             BalanceTimeStamp => 'BalanceTimeStamp',
         }
     );
@@ -55,7 +55,7 @@ Business::PayPal::API::GetBalance - PayPal GetBalance API
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =head1 AUTHORS
 
