@@ -1,5 +1,5 @@
 package Business::PayPal::API::ReauthorizationRequest;
-$Business::PayPal::API::ReauthorizationRequest::VERSION = '0.72';
+$Business::PayPal::API::ReauthorizationRequest::VERSION = '0.73';
 use 5.008001;
 use strict;
 use warnings;
@@ -33,8 +33,8 @@ sub DoReauthorizationRequest {
 
     my $request
         = SOAP::Data->name(
-        DoReauthorizationRequest => \SOAP::Data->value( @ref_trans ) )
-        ->type( "ns:ReauthorizationRequestType" );
+        DoReauthorizationRequest => \SOAP::Data->value(@ref_trans) )
+        ->type("ns:ReauthorizationRequestType");
 
     my $som = $self->doCall( DoReauthorizationReq => $request )
         or return;
@@ -50,7 +50,8 @@ sub DoReauthorizationRequest {
     $self->getFields(
         $som, $path,
         \%response,
-        {   AuthorizationID => 'AuthorizationID',
+        {
+            AuthorizationID => 'AuthorizationID',
             Amount          => 'Amount',
         }
     );
@@ -70,7 +71,7 @@ Business::PayPal::API::ReauthorizationRequest - PayPal ReauthorizationRequest AP
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =head1 SYNOPSIS
 
