@@ -1,5 +1,5 @@
 package Business::PayPal::API::RefundTransaction;
-$Business::PayPal::API::RefundTransaction::VERSION = '0.72';
+$Business::PayPal::API::RefundTransaction::VERSION = '0.73';
 use 5.008001;
 use strict;
 use warnings;
@@ -45,8 +45,8 @@ sub RefundTransaction {
 
     my $request
         = SOAP::Data->name(
-        RefundTransactionRequest => \SOAP::Data->value( @ref_trans ) )
-        ->type( "ns:RefundTransactionRequestType" );
+        RefundTransactionRequest => \SOAP::Data->value(@ref_trans) )
+        ->type("ns:RefundTransactionRequestType");
 
     my $som = $self->doCall( RefundTransactionReq => $request )
         or return;
@@ -62,7 +62,8 @@ sub RefundTransaction {
     $self->getFields(
         $som, $path,
         \%response,
-        {   RefundTransactionID => 'RefundTransactionID',
+        {
+            RefundTransactionID => 'RefundTransactionID',
             FeeRefundAmount     => 'FeeRefundAmount',
             NetRefundAmount     => 'NetRefundAmount',
             GrossRefundAmount   => 'GrossRefundAmount',
@@ -84,7 +85,7 @@ Business::PayPal::API::RefundTransaction - PayPal RefundTransaction API
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =head1 SYNOPSIS
 
